import gevent.monkey
gevent.monkey.patch_all()
import socket
import SSL


def test():
    context = SSL.Context(SSL.TLSv1_METHOD)
    sock = socket.create_connection(('www.google.com', 443), timeout=2)
    connection = SSL.Connection(context, sock)
    connection.set_connect_state()
    connection.do_handshake()
    connection.send('GET / HTTP/1.1\r\n\r\n')
    print(connection.recv(1024))

if __name__ == '__main__':
    test()



#!/usr/bin/env python

from setuptools import setup, find_packages

setup(name='gevent_openssl',
      version='1.0',
      description='A gevent wrapper for pyOpenSSL',
      author='Phus Lu',
      author_email='phus.lu@gmail.com',
      url='https://github.com/phuslu/gevent_openssl',
      packages=find_packages(),
      zip_safe=False,
      include_package_data=True,
      license='New BSD',
      platforms='any',
      install_requires=['pyOpenSSL>=0.11', 'gevent'])
